"""
Profiling plugin abstract class module.
"""
from __future__ import annotations

from nefertem_core.plugins.builder import PluginBuilder


class ProfilingPluginBuilder(PluginBuilder):
    """
    Profiling plugin builder.
    """
